==> wcwidth-0.0.1.tar.gz: wcwidth-0.0.1/wcwidth/table_comb.py <==
# Generated: 2014-05-05T00:41:21.762641+00:00
# Source: DerivedCombiningClass-6.3.0.txt
# Date:  2013-07-05, 14:08:44 GMT [MD]
NONZERO_COMBINING = (
    (0x0300, 0x034e,),  # Combining Grave Accent  ..Combining Upwards Arrow
    (0x0350, 0x036f,),  # Combining Right Arrowhea..Combining Latin Small Le
    (0x0483, 0x0487,),  # Combining Cyrillic Titlo..Combining Cyrillic Pokry
    (0x0591, 0x05bd,),  # Hebrew Accent Etnahta   ..Hebrew Point Meteg
    (0x05bf, 0x05bf,),  # Hebrew Point Rafe       ..Hebrew Point Rafe
    (0x05c1, 0x05c2,),  # Hebrew Point Shin Dot   ..Hebrew Point Sin Dot
    (0x05c4, 0x05c5,),  # Hebrew Mark Upper Dot   ..Hebrew Mark Lower Dot
    (0x05c7, 0x05c7,),  # Hebrew Point Qamats Qata..Hebrew Point Qamats Qata
    (0x0610, 0x061a,),  # Arabic Sign Sallallahou ..Arabic Small Kasra
    (0x064b, 0x065f,),  # Arabic Fathatan         ..Arabic Wavy Hamza Below
    (0x0670, 0x0670,),  # Arabic Letter Superscrip..Arabic Letter Superscrip
    (0x06d6, 0x06dc,),  # Arabic Small High Ligatu..Arabic Small High Seen
    (0x06df, 0x06e4,),  # Arabic Small High Rounde..Arabic Small High Madda
    (0x06e7, 0x06e8,),  # Arabic Small High Yeh   ..Arabic Small High Noon
    (0x06ea, 0x06ed,),  # Arabic Empty Centre Low ..Arabic Small Low Meem
    (0x0711, 0x0711,),  # Syriac Letter Superscrip..Syriac Letter Superscrip
    (0x0730, 0x074a,),  # Syriac Pthaha Above     ..Syriac Barrekh
    (0x07eb, 0x07f3,),  # Nko Combining Short High..Nko Combining Double Dot
    (0x0816, 0x0819,),  # Samaritan Mark In       ..Samaritan Mark Dagesh
    (0x081b, 0x0823,),  # Samaritan Mark Epentheti..Samaritan Vowel Sign A
    (0x0825, 0x0827,),  # Samaritan Vowel Sign Sho..Samaritan Vowel Sign U
    (0x0829, 0x082d,),  # Samaritan Vowel Sign Lon..Samaritan Mark Nequdaa
    (0x0859, 0x085b,),  # Mandaic Affrication Mark..Mandaic Gemination Mark
    (0x08e4, 0x08fe,),  # Arabic Curly Fatha      ..Arabic Damma With Dot
    (0x093c, 0x093c,),  # Devanagari Sign Nukta   ..Devanagari Sign Nukta
    (0x094d, 0x094d,),  # Devanagari Sign Virama  ..Devanagari Sign Virama
    (0x0951, 0x0954,),  # Devanagari Stress Sign U..Devanagari Acute Accent
    (0x09bc, 0x09bc,),  # Bengali Sign Nukta      ..Bengali Sign Nukta
    (0x09cd, 0x09cd,),  # Bengali Sign Virama     ..Bengali Sign Virama
    (0x0a3c, 0x0a3c,),  # Gurmukhi Sign Nukta     ..Gurmukhi Sign Nukta
    (0x0a4d, 0x0a4d,),  # Gurmukhi Sign Virama    ..Gurmukhi Sign Virama
    (0x0abc, 0x0abc,),  # Gujarati Sign Nukta     ..Gujarati Sign Nukta
    (0x0acd, 0x0acd,),  # Gujarati Sign Virama    ..Gujarati Sign Virama
    (0x0b3c, 0x0b3c,),  # Oriya Sign Nukta        ..Oriya Sign Nukta
    (0x0b4d, 0x0b4d,),  # Oriya Sign Virama       ..Oriya Sign Virama
    (0x0bcd, 0x0bcd,),  # Tamil Sign Virama       ..Tamil Sign Virama
    (0x0c4d, 0x0c4d,),  # Telugu Sign Virama      ..Telugu Sign Virama
    (0x0c55, 0x0c56,),  # Telugu Length Mark      ..Telugu Ai Length Mark
    (0x0cbc, 0x0cbc,),  # Kannada Sign Nukta      ..Kannada Sign Nukta
    (0x0ccd, 0x0ccd,),  # Kannada Sign Virama     ..Kannada Sign Virama
    (0x0d4d, 0x0d4d,),  # Malayalam Sign Virama   ..Malayalam Sign Virama
    (0x0dca, 0x0dca,),  # Sinhala Sign Al-lakuna  ..Sinhala Sign Al-lakuna
    (0x0e38, 0x0e3a,),  # Thai Character Sara U   ..Thai Character Phinthu
    (0x0e48, 0x0e4b,),  # Thai Character Mai Ek   ..Thai Character Mai Chatt
    (0x0eb8, 0x0eb9,),  # Lao Vowel Sign U        ..Lao Vowel Sign Uu
    (0x0ec8, 0x0ecb,),  # Lao Tone Mai Ek         ..Lao Tone Mai Catawa
    (0x0f18, 0x0f19,),  # Tibetan Astrological Sig..Tibetan Astrological Sig
    (0x0f35, 0x0f35,),  # Tibetan Mark Ngas Bzung ..Tibetan Mark Ngas Bzung
    (0x0f37, 0x0f37,),  # Tibetan Mark Ngas Bzung ..Tibetan Mark Ngas Bzung
    (0x0f39, 0x0f39,),  # Tibetan Mark Tsa -phru  ..Tibetan Mark Tsa -phru
    (0x0f71, 0x0f72,),  # Tibetan Vowel Sign Aa   ..Tibetan Vowel Sign I
    (0x0f74, 0x0f74,),  # Tibetan Vowel Sign U    ..Tibetan Vowel Sign U
    (0x0f7a, 0x0f7d,),  # Tibetan Vowel Sign E    ..Tibetan Vowel Sign Oo
    (0x0f80, 0x0f80,),  # Tibetan Vowel Sign Rever..Tibetan Vowel Sign Rever
    (0x0f82, 0x0f84,),  # Tibetan Sign Nyi Zla Naa..Tibetan Mark Halanta
    (0x0f86, 0x0f87,),  # Tibetan Sign Lci Rtags  ..Tibetan Sign Yang Rtags
    (0x0fc6, 0x0fc6,),  # Tibetan Symbol Padma Gda..Tibetan Symbol Padma Gda
    (0x1037, 0x1037,),  # Myanmar Sign Dot Below  ..Myanmar Sign Dot Below
    (0x1039, 0x103a,),  # Myanmar Sign Virama     ..Myanmar Sign Asat
    (0x108d, 0x108d,),  # Myanmar Sign Shan Counci..Myanmar Sign Shan Counci
    (0x135d, 0x135f,),  # Ethiopic Combining Gemin..Ethiopic Combining Gemin
    (0x1714, 0x1714,),  # Tagalog Sign Virama     ..Tagalog Sign Virama
    (0x1734, 0x1734,),  # Hanunoo Sign Pamudpod   ..Hanunoo Sign Pamudpod
    (0x17d2, 0x17d2,),  # Khmer Sign Coeng        ..Khmer Sign Coeng
    (0x17dd, 0x17dd,),  # Khmer Sign Atthacan     ..Khmer Sign Atthacan
    (0x18a9, 0x18a9,),  # Mongolian Letter Ali Gal..Mongolian Letter Ali Gal
    (0x1939, 0x193b,),  # Limbu Sign Mukphreng    ..Limbu Sign Sa-i
    (0x1a17, 0x1a18,),  # Buginese Vowel Sign I   ..Buginese Vowel Sign U
    (0x1a60, 0x1a60,),  # Tai Tham Sign Sakot     ..Tai Tham Sign Sakot
    (0x1a75, 0x1a7c,),  # Tai Tham Sign Tone-1    ..Tai Tham Sign Khuen-lue
    (0x1a7f, 0x1a7f,),  # Tai Tham Combining Crypt..Tai Tham Combining Crypt
    (0x1b34, 0x1b34,),  # Balinese Sign Rerekan   ..Balinese Sign Rerekan
    (0x1b44, 0x1b44,),  # Balinese Adeg Adeg      ..Balinese Adeg Adeg
    (0x1b6b, 0x1b73,),  # Balinese Musical Symbol ..Balinese Musical Symbol
    (0x1baa, 0x1bab,),  # Sundanese Sign Pamaaeh  ..Sundanese Sign Virama
    (0x1be6, 0x1be6,),  # Batak Sign Tompi        ..Batak Sign Tompi
    (0x1bf2, 0x1bf3,),  # Batak Pangolat          ..Batak Panongonan
    (0x1c37, 0x1c37,),  # Lepcha Sign Nukta       ..Lepcha Sign Nukta
    (0x1cd0, 0x1cd2,),  # Vedic Tone Karshana     ..Vedic Tone Prenkha
    (0x1cd4, 0x1ce0,),  # Vedic Sign Yajurvedic Mi..Vedic Tone Rigvedic Kash
    (0x1ce2, 0x1ce8,),  # Vedic Sign Visarga Svari..Vedic Sign Visarga Anuda
    (0x1ced, 0x1ced,),  # Vedic Sign Tiryak       ..Vedic Sign Tiryak
    (0x1cf4, 0x1cf4,),  # Vedic Tone Candra Above ..Vedic Tone Candra Above
    (0x1dc0, 0x1de6,),  # Combining Dotted Grave A..Combining Latin Small Le
    (0x1dfc, 0x1dff,),  # Combining Double Inverte..Combining Right Arrowhea
    (0x20d0, 0x20dc,),  # Combining Left Harpoon A..Combining Four Dots Abov
    (0x20e1, 0x20e1,),  # Combining Left Right Arr..Combining Left Right Arr
    (0x20e5, 0x20f0,),  # Combining Reverse Solidu..Combining Asterisk Above
    (0x2cef, 0x2cf1,),  # Coptic Combining Ni Abov..Coptic Combining Spiritu
    (0x2d7f, 0x2d7f,),  # Tifinagh Consonant Joine..Tifinagh Consonant Joine
    (0x2de0, 0x2dff,),  # Combining Cyrillic Lette..Combining Cyrillic Lette
    (0x302a, 0x302f,),  # Ideographic Level Tone M..Hangul Double Dot Tone M
    (0x3099, 0x309a,),  # Combining Katakana-hirag..Combining Katakana-hirag
    (0xa66f, 0xa66f,),  # Combining Cyrillic Vzmet..Combining Cyrillic Vzmet
    (0xa674, 0xa67d,),  # Combining Cyrillic Lette..Combining Cyrillic Payer
    (0xa69f, 0xa69f,),  # Combining Cyrillic Lette..Combining Cyrillic Lette
    (0xa6f0, 0xa6f1,),  # Bamum Combining Mark Koq..Bamum Combining Mark Tuk
    (0xa806, 0xa806,),  # Syloti Nagri Sign Hasant..Syloti Nagri Sign Hasant
    (0xa8c4, 0xa8c4,),  # Saurashtra Sign Virama  ..Saurashtra Sign Virama
    (0xa8e0, 0xa8f1,),  # Combining Devanagari Dig..Combining Devanagari Sig
    (0xa92b, 0xa92d,),  # Kayah Li Tone Plophu    ..Kayah Li Tone Calya Plop
    (0xa953, 0xa953,),  # Rejang Virama           ..Rejang Virama
    (0xa9b3, 0xa9b3,),  # Javanese Sign Cecak Telu..Javanese Sign Cecak Telu
    (0xa9c0, 0xa9c0,),  # Javanese Pangkon        ..Javanese Pangkon
    (0xaab0, 0xaab0,),  # Tai Viet Mai Kang       ..Tai Viet Mai Kang
    (0xaab2, 0xaab4,),  # Tai Viet Vowel I        ..Tai Viet Vowel U
    (0xaab7, 0xaab8,),  # Tai Viet Mai Khit       ..Tai Viet Vowel Ia
    (0xaabe, 0xaabf,),  # Tai Viet Vowel Am       ..Tai Viet Tone Mai Ek
    (0xaac1, 0xaac1,),  # Tai Viet Tone Mai Tho   ..Tai Viet Tone Mai Tho
    (0xaaf6, 0xaaf6,),  # Meetei Mayek Virama     ..Meetei Mayek Virama
    (0xabed, 0xabed,),  # Meetei Mayek Apun Iyek  ..Meetei Mayek Apun Iyek
    (0xfb1e, 0xfb1e,),  # Hebrew Point Judeo-spani..Hebrew Point Judeo-spani
    (0xfe20, 0xfe26,),  # Combining Ligature Left ..Combining Conjoining Mac
    (0x101fd, 0x101fd,),  # Phaistos Disc Sign Combi..Phaistos Disc Sign Combi
    (0x10a0d, 0x10a0d,),  # Kharoshthi Sign Double R..Kharoshthi Sign Double R
    (0x10a0f, 0x10a0f,),  # Kharoshthi Sign Visarga ..Kharoshthi Sign Visarga
    (0x10a38, 0x10a3a,),  # Kharoshthi Sign Bar Abov..Kharoshthi Sign Dot Belo
    (0x10a3f, 0x10a3f,),  # Kharoshthi Virama       ..Kharoshthi Virama
    (0x11046, 0x11046,),  # Brahmi Virama           ..Brahmi Virama
    (0x110b9, 0x110ba,),  # Kaithi Sign Virama      ..Kaithi Sign Nukta
    (0x11100, 0x11102,),  # Chakma Sign Candrabindu ..Chakma Sign Visarga
    (0x11133, 0x11134,),  # Chakma Virama           ..Chakma Maayyaa
    (0x111c0, 0x111c0,),  # Sharada Sign Virama     ..Sharada Sign Virama
    (0x116b6, 0x116b7,),  # Takri Sign Virama       ..Takri Sign Nukta
    (0x1d165, 0x1d169,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d16d, 0x1d172,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d17b, 0x1d182,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d185, 0x1d18b,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d1aa, 0x1d1ad,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d242, 0x1d244,),  # Combining Greek Musical ..Combining Greek Musical
)

==> wcwidth-0.1.2.tar.gz: wcwidth-0.1.2/wcwidth/table_comb.py <==
# Generated: 2014-10-28T14:29:37.656366+00:00
# Source: DerivedCombiningClass-7.0.0.txt
# Date:  2014-02-07, 18:42:08 GMT [MD]
NONZERO_COMBINING = (
    (0x0300, 0x034e,),  # Combining Grave Accent  ..Combining Upwards Arrow
    (0x0350, 0x036f,),  # Combining Right Arrowhea..Combining Latin Small Le
    (0x0483, 0x0487,),  # Combining Cyrillic Titlo..Combining Cyrillic Pokry
    (0x0591, 0x05bd,),  # Hebrew Accent Etnahta   ..Hebrew Point Meteg
    (0x05bf, 0x05bf,),  # Hebrew Point Rafe       ..Hebrew Point Rafe
    (0x05c1, 0x05c2,),  # Hebrew Point Shin Dot   ..Hebrew Point Sin Dot
    (0x05c4, 0x05c5,),  # Hebrew Mark Upper Dot   ..Hebrew Mark Lower Dot
    (0x05c7, 0x05c7,),  # Hebrew Point Qamats Qata..Hebrew Point Qamats Qata
    (0x0610, 0x061a,),  # Arabic Sign Sallallahou ..Arabic Small Kasra
    (0x064b, 0x065f,),  # Arabic Fathatan         ..Arabic Wavy Hamza Below
    (0x0670, 0x0670,),  # Arabic Letter Superscrip..Arabic Letter Superscrip
    (0x06d6, 0x06dc,),  # Arabic Small High Ligatu..Arabic Small High Seen
    (0x06df, 0x06e4,),  # Arabic Small High Rounde..Arabic Small High Madda
    (0x06e7, 0x06e8,),  # Arabic Small High Yeh   ..Arabic Small High Noon
    (0x06ea, 0x06ed,),  # Arabic Empty Centre Low ..Arabic Small Low Meem
    (0x0711, 0x0711,),  # Syriac Letter Superscrip..Syriac Letter Superscrip
    (0x0730, 0x074a,),  # Syriac Pthaha Above     ..Syriac Barrekh
    (0x07eb, 0x07f3,),  # Nko Combining Short High..Nko Combining Double Dot
    (0x0816, 0x0819,),  # Samaritan Mark In       ..Samaritan Mark Dagesh
    (0x081b, 0x0823,),  # Samaritan Mark Epentheti..Samaritan Vowel Sign A
    (0x0825, 0x0827,),  # Samaritan Vowel Sign Sho..Samaritan Vowel Sign U
    (0x0829, 0x082d,),  # Samaritan Vowel Sign Lon..Samaritan Mark Nequdaa
    (0x0859, 0x085b,),  # Mandaic Affrication Mark..Mandaic Gemination Mark
    (0x08e4, 0x08ff,),  # Arabic Curly Fatha      ..
    (0x093c, 0x093c,),  # Devanagari Sign Nukta   ..Devanagari Sign Nukta
    (0x094d, 0x094d,),  # Devanagari Sign Virama  ..Devanagari Sign Virama
    (0x0951, 0x0954,),  # Devanagari Stress Sign U..Devanagari Acute Accent
    (0x09bc, 0x09bc,),  # Bengali Sign Nukta      ..Bengali Sign Nukta
    (0x09cd, 0x09cd,),  # Bengali Sign Virama     ..Bengali Sign Virama
    (0x0a3c, 0x0a3c,),  # Gurmukhi Sign Nukta     ..Gurmukhi Sign Nukta
    (0x0a4d, 0x0a4d,),  # Gurmukhi Sign Virama    ..Gurmukhi Sign Virama
    (0x0abc, 0x0abc,),  # Gujarati Sign Nukta     ..Gujarati Sign Nukta
    (0x0acd, 0x0acd,),  # Gujarati Sign Virama    ..Gujarati Sign Virama
    (0x0b3c, 0x0b3c,),  # Oriya Sign Nukta        ..Oriya Sign Nukta
    (0x0b4d, 0x0b4d,),  # Oriya Sign Virama       ..Oriya Sign Virama
    (0x0bcd, 0x0bcd,),  # Tamil Sign Virama       ..Tamil Sign Virama
    (0x0c4d, 0x0c4d,),  # Telugu Sign Virama      ..Telugu Sign Virama
    (0x0c55, 0x0c56,),  # Telugu Length Mark      ..Telugu Ai Length Mark
    (0x0cbc, 0x0cbc,),  # Kannada Sign Nukta      ..Kannada Sign Nukta
    (0x0ccd, 0x0ccd,),  # Kannada Sign Virama     ..Kannada Sign Virama
    (0x0d4d, 0x0d4d,),  # Malayalam Sign Virama   ..Malayalam Sign Virama
    (0x0dca, 0x0dca,),  # Sinhala Sign Al-lakuna  ..Sinhala Sign Al-lakuna
    (0x0e38, 0x0e3a,),  # Thai Character Sara U   ..Thai Character Phinthu
    (0x0e48, 0x0e4b,),  # Thai Character Mai Ek   ..Thai Character Mai Chatt
    (0x0eb8, 0x0eb9,),  # Lao Vowel Sign U        ..Lao Vowel Sign Uu
    (0x0ec8, 0x0ecb,),  # Lao Tone Mai Ek         ..Lao Tone Mai Catawa
    (0x0f18, 0x0f19,),  # Tibetan Astrological Sig..Tibetan Astrological Sig
    (0x0f35, 0x0f35,),  # Tibetan Mark Ngas Bzung ..Tibetan Mark Ngas Bzung
    (0x0f37, 0x0f37,),  # Tibetan Mark Ngas Bzung ..Tibetan Mark Ngas Bzung
    (0x0f39, 0x0f39,),  # Tibetan Mark Tsa -phru  ..Tibetan Mark Tsa -phru
    (0x0f71, 0x0f72,),  # Tibetan Vowel Sign Aa   ..Tibetan Vowel Sign I
    (0x0f74, 0x0f74,),  # Tibetan Vowel Sign U    ..Tibetan Vowel Sign U
    (0x0f7a, 0x0f7d,),  # Tibetan Vowel Sign E    ..Tibetan Vowel Sign Oo
    (0x0f80, 0x0f80,),  # Tibetan Vowel Sign Rever..Tibetan Vowel Sign Rever
    (0x0f82, 0x0f84,),  # Tibetan Sign Nyi Zla Naa..Tibetan Mark Halanta
    (0x0f86, 0x0f87,),  # Tibetan Sign Lci Rtags  ..Tibetan Sign Yang Rtags
    (0x0fc6, 0x0fc6,),  # Tibetan Symbol Padma Gda..Tibetan Symbol Padma Gda
    (0x1037, 0x1037,),  # Myanmar Sign Dot Below  ..Myanmar Sign Dot Below
    (0x1039, 0x103a,),  # Myanmar Sign Virama     ..Myanmar Sign Asat
    (0x108d, 0x108d,),  # Myanmar Sign Shan Counci..Myanmar Sign Shan Counci
    (0x135d, 0x135f,),  # Ethiopic Combining Gemin..Ethiopic Combining Gemin
    (0x1714, 0x1714,),  # Tagalog Sign Virama     ..Tagalog Sign Virama
    (0x1734, 0x1734,),  # Hanunoo Sign Pamudpod   ..Hanunoo Sign Pamudpod
    (0x17d2, 0x17d2,),  # Khmer Sign Coeng        ..Khmer Sign Coeng
    (0x17dd, 0x17dd,),  # Khmer Sign Atthacan     ..Khmer Sign Atthacan
    (0x18a9, 0x18a9,),  # Mongolian Letter Ali Gal..Mongolian Letter Ali Gal
    (0x1939, 0x193b,),  # Limbu Sign Mukphreng    ..Limbu Sign Sa-i
    (0x1a17, 0x1a18,),  # Buginese Vowel Sign I   ..Buginese Vowel Sign U
    (0x1a60, 0x1a60,),  # Tai Tham Sign Sakot     ..Tai Tham Sign Sakot
    (0x1a75, 0x1a7c,),  # Tai Tham Sign Tone-1    ..Tai Tham Sign Khuen-lue
    (0x1a7f, 0x1a7f,),  # Tai Tham Combining Crypt..Tai Tham Combining Crypt
    (0x1ab0, 0x1abd,),  # (nil)                   ..
    (0x1b34, 0x1b34,),  # Balinese Sign Rerekan   ..Balinese Sign Rerekan
    (0x1b44, 0x1b44,),  # Balinese Adeg Adeg      ..Balinese Adeg Adeg
    (0x1b6b, 0x1b73,),  # Balinese Musical Symbol ..Balinese Musical Symbol
    (0x1baa, 0x1bab,),  # Sundanese Sign Pamaaeh  ..Sundanese Sign Virama
    (0x1be6, 0x1be6,),  # Batak Sign Tompi        ..Batak Sign Tompi
    (0x1bf2, 0x1bf3,),  # Batak Pangolat          ..Batak Panongonan
    (0x1c37, 0x1c37,),  # Lepcha Sign Nukta       ..Lepcha Sign Nukta
    (0x1cd0, 0x1cd2,),  # Vedic Tone Karshana     ..Vedic Tone Prenkha
    (0x1cd4, 0x1ce0,),  # Vedic Sign Yajurvedic Mi..Vedic Tone Rigvedic Kash
    (0x1ce2, 0x1ce8,),  # Vedic Sign Visarga Svari..Vedic Sign Visarga Anuda
    (0x1ced, 0x1ced,),  # Vedic Sign Tiryak       ..Vedic Sign Tiryak
    (0x1cf4, 0x1cf4,),  # Vedic Tone Candra Above ..Vedic Tone Candra Above
    (0x1cf8, 0x1cf9,),  # (nil)                   ..
    (0x1dc0, 0x1df5,),  # Combining Dotted Grave A..
    (0x1dfc, 0x1dff,),  # Combining Double Inverte..Combining Right Arrowhea
    (0x20d0, 0x20dc,),  # Combining Left Harpoon A..Combining Four Dots Abov
    (0x20e1, 0x20e1,),  # Combining Left Right Arr..Combining Left Right Arr
    (0x20e5, 0x20f0,),  # Combining Reverse Solidu..Combining Asterisk Above
    (0x2cef, 0x2cf1,),  # Coptic Combining Ni Abov..Coptic Combining Spiritu
    (0x2d7f, 0x2d7f,),  # Tifinagh Consonant Joine..Tifinagh Consonant Joine
    (0x2de0, 0x2dff,),  # Combining Cyrillic Lette..Combining Cyrillic Lette
    (0x302a, 0x302f,),  # Ideographic Level Tone M..Hangul Double Dot Tone M
    (0x3099, 0x309a,),  # Combining Katakana-hirag..Combining Katakana-hirag
    (0xa66f, 0xa66f,),  # Combining Cyrillic Vzmet..Combining Cyrillic Vzmet
    (0xa674, 0xa67d,),  # Combining Cyrillic Lette..Combining Cyrillic Payer
    (0xa69f, 0xa69f,),  # Combining Cyrillic Lette..Combining Cyrillic Lette
    (0xa6f0, 0xa6f1,),  # Bamum Combining Mark Koq..Bamum Combining Mark Tuk
    (0xa806, 0xa806,),  # Syloti Nagri Sign Hasant..Syloti Nagri Sign Hasant
    (0xa8c4, 0xa8c4,),  # Saurashtra Sign Virama  ..Saurashtra Sign Virama
    (0xa8e0, 0xa8f1,),  # Combining Devanagari Dig..Combining Devanagari Sig
    (0xa92b, 0xa92d,),  # Kayah Li Tone Plophu    ..Kayah Li Tone Calya Plop
    (0xa953, 0xa953,),  # Rejang Virama           ..Rejang Virama
    (0xa9b3, 0xa9b3,),  # Javanese Sign Cecak Telu..Javanese Sign Cecak Telu
    (0xa9c0, 0xa9c0,),  # Javanese Pangkon        ..Javanese Pangkon
    (0xaab0, 0xaab0,),  # Tai Viet Mai Kang       ..Tai Viet Mai Kang
    (0xaab2, 0xaab4,),  # Tai Viet Vowel I        ..Tai Viet Vowel U
    (0xaab7, 0xaab8,),  # Tai Viet Mai Khit       ..Tai Viet Vowel Ia
    (0xaabe, 0xaabf,),  # Tai Viet Vowel Am       ..Tai Viet Tone Mai Ek
    (0xaac1, 0xaac1,),  # Tai Viet Tone Mai Tho   ..Tai Viet Tone Mai Tho
    (0xaaf6, 0xaaf6,),  # Meetei Mayek Virama     ..Meetei Mayek Virama
    (0xabed, 0xabed,),  # Meetei Mayek Apun Iyek  ..Meetei Mayek Apun Iyek
    (0xfb1e, 0xfb1e,),  # Hebrew Point Judeo-spani..Hebrew Point Judeo-spani
    (0xfe20, 0xfe2d,),  # Combining Ligature Left ..
    (0x101fd, 0x101fd,),  # Phaistos Disc Sign Combi..Phaistos Disc Sign Combi
    (0x102e0, 0x102e0,),  # (nil)                   ..
    (0x10376, 0x1037a,),  # (nil)                   ..
    (0x10a0d, 0x10a0d,),  # Kharoshthi Sign Double R..Kharoshthi Sign Double R
    (0x10a0f, 0x10a0f,),  # Kharoshthi Sign Visarga ..Kharoshthi Sign Visarga
    (0x10a38, 0x10a3a,),  # Kharoshthi Sign Bar Abov..Kharoshthi Sign Dot Belo
    (0x10a3f, 0x10a3f,),  # Kharoshthi Virama       ..Kharoshthi Virama
    (0x10ae5, 0x10ae6,),  # (nil)                   ..
    (0x11046, 0x11046,),  # Brahmi Virama           ..Brahmi Virama
    (0x1107f, 0x1107f,),  # (nil)                   ..
    (0x110b9, 0x110ba,),  # Kaithi Sign Virama      ..Kaithi Sign Nukta
    (0x11100, 0x11102,),  # Chakma Sign Candrabindu ..Chakma Sign Visarga
    (0x11133, 0x11134,),  # Chakma Virama           ..Chakma Maayyaa
    (0x11173, 0x11173,),  # (nil)                   ..
    (0x111c0, 0x111c0,),  # Sharada Sign Virama     ..Sharada Sign Virama
    (0x11235, 0x11236,),  # (nil)                   ..
    (0x112e9, 0x112ea,),  # (nil)                   ..
    (0x1133c, 0x1133c,),  # (nil)                   ..
    (0x1134d, 0x1134d,),  # (nil)                   ..
    (0x11366, 0x1136c,),  # (nil)                   ..
    (0x11370, 0x11374,),  # (nil)                   ..
    (0x114c2, 0x114c3,),  # (nil)                   ..
    (0x115bf, 0x115c0,),  # (nil)                   ..
    (0x1163f, 0x1163f,),  # (nil)                   ..
    (0x116b6, 0x116b7,),  # Takri Sign Virama       ..Takri Sign Nukta
    (0x16af0, 0x16af4,),  # (nil)                   ..
    (0x16b30, 0x16b36,),  # (nil)                   ..
    (0x1bc9e, 0x1bc9e,),  # (nil)                   ..
    (0x1d165, 0x1d169,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d16d, 0x1d172,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d17b, 0x1d182,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d185, 0x1d18b,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d1aa, 0x1d1ad,),  # Musical Symbol Combining..Musical Symbol Combining
    (0x1d242, 0x1d244,),  # Combining Greek Musical ..Combining Greek Musical
    (0x1e8d0, 0x1e8d6,),  # (nil)                   ..
)
